function [out] = CycleTest
% returns pos,  which is really a status
%
% pos takes the values:
%    +1      for left 
%    -1      for right
%     0      if no sensors are triggered
%     3      if both sensors are triggered
%   100      if it didn't try to move left
%  -100      if it didn't try to move right
%

    nCycles = 15000;
    startPos = zeros(nCycles,1);
    stopPos  = zeros(nCycles,1);
    vMon     = zeros(nCycles,1);
    [dio, ao, ai] = resetFlipper;
    pause(0.1);
    filename = sprintf('%5.5f-Cycles.mat',now);
    out = struct([]);
    missed = 0;
    for ii = 1:nCycles
        
        %% Do cycle
        out(ii).start = checkPosition(dio);
        if (out(ii).start == 1)
            out(ii).move = -1;
            [out(ii).vMon out(ii).duration] = moveRight(dio, ao, ai);
        else
            out(ii).move = 1;
            [out(ii).vMon out(ii).duration] = moveLeft(dio, ao, ai);
        end
        % Cool down with 50% duty cycle
        pause(out(ii).duration);
        
        out(ii).stop = checkPosition(dio);
        fprintf(1, 'Cycle %04i, StartPos = %d\r', ii, out(ii).start); 
    %% Evaluate success
        
        if( (out(ii).stop == 1 && out(ii).start == -1) || ...
                (out(ii).stop == -1 && out(ii).start == 1) )
            missed = 0;
            out(ii).success = 1;
        else
            fprintf(1, ' ------------ ERROR ------------ \n');
            missed = missed + 1;
            out(ii).success = 0;
        end
        
        if(missed >= 5)
            out(ii).reset = 1;
            [dio, ao, ai] = resetFlipper;
            missed = 0;
        else
            out(ii).reset = 0;
        end
        
   %% Plot figure
        subplot(2,1,1)
        plot(1:ii, abs([out.vMon]), '*');
        ylabel('Current monitor [V]');
        subplot(2,1,2)
        plot(1:ii, [out.duration],'*');
        ylabel('Movement duration');
        xlabel('Cycle Number');
        save(filename, 'ii', 'out');
    end

end
